@@ -108,7 +108,7 @@ def _execute_iterator(cmd, err_out=False):
 def _get_insight_name():
     # Regex extract alphabeticals and stick them back together snake case
     words = re.findall("[a-zA-Z]+", Path.cwd().name)
-    return "_".join(word.lower() for word in words)
+    return " ".join(word.lower() for word in words).title()
 
 
 def _get_create_hashname():
